
#Author: Sreekumar T Balan
#Modified on: 05-04-2008


#USE AT YOUR OWN RISK!!!!
print(war<-c("USE AT YOUR OWN RISK!!!!"))

# Packages needed
checkCODA<-library(coda,logical.return=TRUE)
checkMASS<-library(MASS,logical.return=TRUE)
checkHMISC<-library(Hmisc,logical.return=TRUE)
checkGRID<-library(grid,logical.return=TRUE)
checkHDRCDE<-library(hdrcde,logical.return=TRUE)
checkASH<-library(ash,logical.return=TRUE)

# Data files

mcdata<-"extract.dat"

# Constats needed
d2s<-86400
G<-6.673e-11
m_sun<-1.989e30
m_jup<-1.898e27
AU<-1.49598e11




if(checkCODA=='TRUE' && checkMASS=='TRUE' && checkHMISC=='TRUE' && checkHDRCDE=='TRUE' && checkASH=='TRUE'){



# Read mcmc extract
	ext<-read.table(mcdata,head=TRUE);	
	dm<-dim(ext);

	opt<-ext[1:dm[1],1:(dm[2]-1)];
	mc<-mcmc(opt);
	

# Find the medians
	mdn<-vector(mode="numeric",dm[2]+1);
	for(i in 1:(dm[2]-1) ){
		mdn[i]<-median(opt[1:dm[1],i]);
	};




############### function to plot radial velocity data #############
	orbit.plot<-function(rvdata){

	# Read data files
		dat<-read.table(rvdata,head=FALSE);	
		dmd<-dim(dat);
	# min and max of radial velocity data
		mdn[(dm[2])]=dat[1,1];
		mdn[(dm[2]+1)]=dat[dmd[1],1];

	# Write the medians to orb_vals.dat and run plotmaker	
		write.matrix(mdn,file="orb_vals.dat");
		system('plot_maker');

	# Plot the radial velocity curve with errorbars	
		datp<-read.table("orb_plot.dat",head=FALSE);
		xx<-datp$V1;
		yy<-datp$V2;
		plot(xx,yy,type='l',col="red",lwd=2,
			main=x<-c("Radial Velocity Curve for",rvdata),
			xlab="Julian Date",
			ylab="Velocity (m/s)" );
		x<-dat$V1;
		y<-dat$V2;
		delta<-dat$V3;
		errbar(x,y,y+delta,y-delta,col="blue",lwd='2',add=TRUE);
	};

	

########### Print the orbital parametes ###########################
	print.median<-function(rvdata,mstar){

	

	# Read data files
		dat<-read.table(rvdata,head=FALSE);	
		dmd<-dim(dat);
	# min and max of radial velocity data
		mdn[(dm[2])]=dat[1,1];
		mdn[(dm[2]+1)]=dat[dmd[1],1];
	# Calculate the mp_Sini,ap_Sini and periastron passage
	
		as_sini=ext$K*ext$T*d2s*sqrt(1-ext$e*ext$e)/(2*pi*1000);
		mp_sini=ext$K*(mstar*m_sun)^(2/3)*(ext$T*d2s)^(1/3)*sqrt(1-ext$e*ext$e)/((2*pi*G)^(1/3)*m_jup);
		a<-mstar*m_sun*as_sini*1000/(mp_sini*m_jup*AU);
		t0<-mdn[(dm[2])];
		Tp<-t0+(1-ext$X)*ext$T;

		oth_para<-cbind(as_sini,mp_sini,Tp,a);
		mc_oth<-mcmc(oth_para);

		mdn_as<-median(as_sini);
		mdn_mp<-median(mp_sini);
		mdn_tp<-median(Tp);
		mdn_aa<-median(a);

		summ<-summary(mc);
		print(summ);
		summo<-summary(mc_oth);
		print(summo);

		print(pp<-c("Period",mdn[1]) );
		print(pp<-c("Amplitude",mdn[2]) );
		print(pp<-c("Systematic Velocity",mdn[3]) );
		print(pp<-c("Eccentricity",mdn[4]) );
		print(pp<-c("Longitude of Periastron",mdn[5]*180/pi) );
		print(pp<-c("Periatron Passage Factor",mdn[6]) );
		print(pp<-c("Noise Factor",mdn[7]) );

		print(pp<-c("as_sin_i",mdn_as) );
		print(pp<-c("mp_sin_i",mdn_mp) );
		print(pp<-c("Perastron Passage",mdn_tp) );
		print(pp<-c("Length of the Semimajor axis",mdn_aa) );
		print(pp<-c("first data=",t0));

		#print(pp<-c("Statistical summary for parameters") );
		#summary(mc);
		#summary(mc_oth);

	};
########### Print the orbital parametes mode ###########################
	print.hdrmode<-function(rvdata,mstar){

	

	# Read data files
		dat<-read.table(rvdata,head=FALSE);	
		dmd<-dim(dat);
	# min and max of radial velocity data
		mdn[(dm[2])]=dat[1,1];
		mdn[(dm[2]+1)]=dat[dmd[1],1];
	# Calculate the mp_Sini,ap_Sini and periastron passage
	
		as_sini=ext$K*ext$T*d2s*sqrt(1-ext$e*ext$e)/(2*pi*1000);
		mp_sini=ext$K*(mstar*m_sun)^(2/3)*(ext$T*d2s)^(1/3)*sqrt(1-ext$e*ext$e)/((2*pi*G)^(1/3)*m_jup);
		a<-mstar*m_sun*as_sini*1000/(mp_sini*m_jup*AU);
		t0<-mdn[(dm[2])];
		Tp<-t0+(1-ext$X)*ext$T;

		h2d<-hdr(opt$T,prob=68.3);
		print(pp<-c("T",h2d$hdr[1],h2d$mode,h2d$hdr[2]),digits=4 );
		h2d<-hdr(opt$K,prob=68.3)
		print(pp<-c("K",h2d$hdr[1],h2d$mode,h2d$hdr[2]) );
		h2d<-hdr(opt$V,prob=68.3)
		print(pp<-c("V",h2d$hdr[1],h2d$mode,h2d$hdr[2]) );
		h2d<-hdr(opt$e,prob=68.3)
		print(pp<-c("e",h2d$hdr[1],h2d$mode,h2d$hdr[2]) );
		h2d<-hdr(opt$w,prob=68.3)
		print(pp<-c("w",h2d$hdr[1],h2d$mode,h2d$hdr[2]) );
		h2d<-hdr(opt$X,prob=68.3)
		print(pp<-c("X",h2d$hdr[1],h2d$mode,h2d$hdr[2]) );
		h2d<-hdr(opt$s,prob=68.3)
		print(pp<-c("s",h2d$hdr[1],h2d$mode,h2d$hdr[2]) );

		h2d<-hdr(Tp,prob=68.3)
		print(pp<-c("Tp",h2d$hdr[1],h2d$mode,h2d$hdr[2]) );
		h2d<-hdr(mp_sini,prob=68.3)
		print(pp<-c("mp_sini",h2d$hdr[1],h2d$mode,h2d$hdr[2]) );
		h2d<-hdr(a,prob=68.3)
		print(pp<-c("a",h2d$hdr[1],h2d$mode,h2d$hdr[2]) )


	};


############# to make the plots ################
	doplot<-function(name,title, ...) { do.call(  name,
		 list(...,strip=function(which.panel, ...) { 
  			grid.rect(gp=gpar(fill="grey90")); grid.text(title) 
			} )  ) 
	};

################# trace plots of parameters #####################
	trace.model<-function(){
		plot <- vector("list", 7);
		iter<-data.frame(x=1:dm[1])

		plot[[1]] <- doplot("xyplot","Orbital Period T (days)", T~ iter|1,data=ext,
			xlab="Iterations",ylab="Period",type="l",col="black");

		plot[[2]] <- doplot("xyplot","Amplitude K (m/s)", K~ iter|1,data=ext,
			xlab="Iterations",ylab="Amplitude",type="l",col="black");

		plot[[3]] <- doplot("xyplot","Systematic Velocity (m/s)", V~ iter|1,data=ext,
			xlab="Iterations",ylab="Systematic V",type="l",col="black");

		plot[[4]] <- doplot("xyplot","Eccentricity e", e~ iter|1,data=ext,
			xlab="Iterations",ylab="Eccentricity",type="l",col="black");

		plot[[5]] <- doplot("xyplot","Longitude of Periastron (rad)", w~ iter|1,data=ext,
			xlab="Iterations",ylab="Longitude of Periastron",type="l",col="black");

		plot[[6]] <- doplot("xyplot","Periaston Passage", X~ iter|1,data=ext,
			xlab="Iterations",ylab="Periatron Time",type="l",col="black");

		plot[[7]] <- doplot("xyplot","Noise Factor (m/s)", s~ iter|1,data=ext,
			xlab="Iterations",ylab="Noise Factor",type="l",col="black");

		grid.newpage();
		pushViewport(viewport(layout=grid.layout(4, 2)));

		count<-1

		for (i in 1:3){
			for (j in 1:2){
				pushViewport(viewport(layout.pos.row=i,layout.pos.col=j));
				print(plot[[count]],newpage=FALSE,
					panel.width=list(2.5, "inches"),
        				panel.height=list(0.95, "inches")
				);
				popViewport();
				count<-count+1;
			}		
		}

		pushViewport(viewport(layout.pos.row=4,layout.pos.col=1));
		print(plot[[7]],newpage=FALSE,
			panel.width=list(2.5, "inches"),
        		panel.height=list(0.95, "inches")
		);
		popViewport();
	};

############ plot histograms and densities ##################################
	hist.dens.model<-function(){

		plot <- vector("list", 7);
		
		tpar<-trellis.par.get(name="plot.polygon");
		tpar$col="#e5e5e5";
		trellis.par.set(name="plot.polygon",tpar);

		plot[[1]]<-doplot("histogram","Orbital Period (days)",~T|1,data=ext,type="density",nint=50,
					panel= function(x, ...){ 
						panel.histogram(x, ...)
  						panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					}
				  );
  
		plot[[2]]<-doplot("histogram","Amplitude (m/s)",~K|1,data=ext,type="density",nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					}
				 );
  
		plot[[3]]<-doplot("histogram","Systematic Velocity (m/s)",~V|1,data=ext,type="density",nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE)
					 } 
				);
  
		plot[[4]]<-doplot("histogram","Eccentricity",~e|1,data=ext,type="density",nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					} 
				);
  
		plot[[5]]<-doplot("histogram","Longitude of Periastron (rad)",~w|1,data=ext,type="density",nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					}  
				);
  
		plot[[6]]<-doplot("histogram","Periastron Passage",~X|1,data=ext,type="density",nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					}  
				);
  
		plot[[7]]<-doplot("histogram","Noise Factor (m/s)",~s|1,data=ext,type="density",nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					}  
				);


		grid.newpage();
		pushViewport(viewport(layout=grid.layout(4, 2)));

		count<-1;

		for (i in 1:3){
  			for (j in 1:2){
    				pushViewport(viewport(layout.pos.row=i,layout.pos.col=j))
    				print(plot[[count]],newpage=FALSE,
    					panel.width=list(2.4, "inches"),
    					panel.height=list(0.95, "inches")
				);
    				popViewport();
    				count<-count+1;
  			}
		}

		pushViewport(viewport(layout.pos.row=4,layout.pos.col=1));
		print(plot[[7]],newpage=FALSE,
			panel.width=list(2.4, "inches"),
			panel.height=list(0.95, "inches")
		);
		popViewport();
	};

################## plot histograms and desities of derived qantities#######
	hist.dens.other<-function(rvdata,mstar){


	# Read data files
		dat<-read.table(rvdata,head=FALSE);	
		dmd<-dim(dat);
	# min and max of radial velocity data
		mdn[(dm[2])]=dat[1,1];
		mdn[(dm[2]+1)]=dat[dmd[1],1];
	# Calculate the mp_Sini,ap_Sini and periastron passage	
		as_sini=ext$K*ext$T*d2s*sqrt(1-ext$e*ext$e)/(2*pi*1000);
		mp_sini=ext$K*(mstar*m_sun)^(2/3)*(ext$T*d2s)^(1/3)*sqrt(1-ext$e*ext$e)/((2*pi*G)^(1/3)*m_jup);
		aa<-mstar*m_sun*as_sini*1000/(mp_sini*m_jup*AU);
		t0<-mdn[(dm[2])];
		tp<-t0+(1-ext$X)*ext$T;

		plot<-vector("list", 4);

		tpar<-trellis.par.get(name="plot.polygon");
		tpar$col="#e5e5e5";
		trellis.par.set(name="plot.polygon",tpar);

		plot[[1]]<-doplot("histogram",expression(paste(a[s],"sini")),~as_sini|1,nint=20,type="density",
			panel= function(x, ...){
  				panel.histogram(x, ...)
  				panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab=expression(paste(a[s],"sini (km)"))
		);
  
		plot[[2]]<-doplot("histogram",expression(paste(m[p],"sini ")),~mp_sini|1,nint=20,type="density",
			panel= function(x, ...){
  				panel.histogram(x, ...)
  				panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab=expression(paste(m[p],"sini (in units of mass of the Jupiter)")) 
		);
  
		plot[[3]]<-doplot("histogram","Length of The Semi-major Axis",~aa|1,nint=20,type="density",
			panel= function(x, ...){
  				panel.histogram(x, ...)
  				panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab="Length of The Semi-major Axis (AU)" 
		);
  
		plot[[4]]<-doplot("histogram","Periastron Passage",~tp|1,nint=20,type="density",
			panel= function(x, ...){
 			panel.histogram(x, ...)
  			panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) },
			xlab="Periastron Passage"  
		);

		grid.newpage()
		pushViewport(viewport(layout=grid.layout(2, 2)))

		count<-1

		for (i in 1:2){
  			for (j in 1:2){
    				pushViewport(viewport(layout.pos.row=i,layout.pos.col=j))
    				print(plot[[count]],newpage=FALSE,
    					panel.width=list(2.4, "inches"),
   					panel.height=list(2.25, "inches")
				);
   				popViewport();
    				count<-count+1;
  			}
		}

		popViewport();
	};

############ plot histograms and densities of all paras##################################
	hist.dens.all<-function(rvdata,mstar){


	# Read data files
		dat<-read.table(rvdata,head=FALSE);	
		dmd<-dim(dat);
	# min and max of radial velocity data
		mdn[(dm[2])]=dat[1,1];
		mdn[(dm[2]+1)]=dat[dmd[1],1];
	# Calculate the mp_Sini,ap_Sini and periastron passage	
		as_sini=ext$K*ext$T*d2s*sqrt(1-ext$e*ext$e)/(2*pi*1000);
		mp_sini=ext$K*(mstar*m_sun)^(2/3)*(ext$T*d2s)^(1/3)*sqrt(1-ext$e*ext$e)/((2*pi*G)^(1/3)*m_jup);
		aa<-mstar*m_sun*as_sini*1000/(mp_sini*m_jup*AU);
		t0<-mdn[(dm[2])];
		tp<-t0+(1-ext$X)*ext$T;

		plot <- vector("list", 10);
		
		tpar<-trellis.par.get(name="plot.polygon");
		tpar$col="#e5e5e5";
		trellis.par.set(name="plot.polygon",tpar);

		plot[[1]]<-doplot("histogram","Orbital Period (days)",~T|1,data=ext,nint=50,
					panel= function(x, ...){ 
						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Period T in days"
				  );
  
		plot[[2]]<-doplot("histogram","Amplitude (m/s)",~K|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Amplitude K in m/s"
				 );
  
		plot[[3]]<-doplot("histogram","Systematic Velocity (m/s)",~V|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE)
					 },
					 xlab="Systemaic Velocity V in m/s" 
				);
  
		plot[[4]]<-doplot("histogram","Eccentricity",~e|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Eccentricity e"
				);
  
		plot[[5]]<-doplot("histogram","Longitude of Periastron (rad)",~w|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Longitude of periastron w"  
				);
  
		plot[[6]]<-doplot("histogram","Periastron Passage",~X|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Periastron passage X"  
				);
  
		plot[[7]]<-doplot("histogram","Noise Factor (m/s)",~s|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Noise factor s"  
				);
		plot[[8]]<-doplot("histogram",expression(paste(m[p],"sini ")),~mp_sini|1,nint=50,
			panel= function(x, ...){
  				panel.histogram(x, ...)
  				#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab=expression(paste(m[p],"sini (in units of mass of the Jupiter)")) 
		);
  
		plot[[9]]<-doplot("histogram","Length of The Semi-major Axis",~aa|1,nint=50,
			panel= function(x, ...){
  				panel.histogram(x, ...)
  				#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab="Length of The Semi-major Axis (AU)" 
		);
  
		plot[[10]]<-doplot("histogram","Periastron Passage",~tp|1,nint=50,
			panel= function(x, ...){
 			panel.histogram(x, ...)
  			#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab="Periastron Passage"  
		);


		grid.newpage();
		pushViewport(viewport(layout=grid.layout(5, 2)));

		count<-1;

		for (i in 1:5){
  			for (j in 1:2){
    				pushViewport(viewport(layout.pos.row=i,layout.pos.col=j))
    				print(plot[[count]],newpage=FALSE,
    					panel.width=list(2.4, "inches"),
    					panel.height=list(0.75, "inches")
				);
    				popViewport();
    				count<-count+1;
  			}
		}

	};

############ plot histograms and densities of all paras##################################
	hist.dens.all<-function(rvdata,mstar){


	# Read data files
		dat<-read.table(rvdata,head=FALSE);	
		dmd<-dim(dat);
	# min and max of radial velocity data
		mdn[(dm[2])]=dat[1,1];
		mdn[(dm[2]+1)]=dat[dmd[1],1];
	# Calculate the mp_Sini,ap_Sini and periastron passage	
		as_sini=ext$K*ext$T*d2s*sqrt(1-ext$e*ext$e)/(2*pi*1000);
		mp_sini=ext$K*(mstar*m_sun)^(2/3)*(ext$T*d2s)^(1/3)*sqrt(1-ext$e*ext$e)/((2*pi*G)^(1/3)*m_jup);
		aa<-mstar*m_sun*as_sini*1000/(mp_sini*m_jup*AU);
		t0<-mdn[(dm[2])];
		tp<-t0+(1-ext$X)*ext$T;

		plot <- vector("list", 10);
		
		tpar<-trellis.par.get(name="plot.polygon");
		tpar$col="#e5e5e5";
		trellis.par.set(name="plot.polygon",tpar);

		plot[[1]]<-doplot("histogram","Orbital Period (days)",~T|1,data=ext,nint=50,
					panel= function(x, ...){ 
						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Period T in days"
				  );
  
		plot[[2]]<-doplot("histogram","Amplitude (m/s)",~K|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Amplitude K in m/s"
				 );
  
		plot[[3]]<-doplot("histogram","Systematic Velocity (m/s)",~V|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE)
					 },
					 xlab="Systemaic Velocity V in m/s" 
				);
  
		plot[[4]]<-doplot("histogram","Eccentricity",~e|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Eccentricity e"
				);
  
		plot[[5]]<-doplot("histogram","Longitude of Periastron (rad)",~w|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Longitude of periastron w"  
				);
  
		plot[[6]]<-doplot("histogram","Periastron Passage",~X|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Periastron passage X"  
				);
  
		plot[[7]]<-doplot("histogram","Noise Factor (m/s)",~s|1,data=ext,nint=50,
					panel= function(x, ...){
  						panel.histogram(x, ...)
  						#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
					},
					xlab="Noise factor s"  
				);
		plot[[8]]<-doplot("histogram",expression(paste(m[p],"sini ")),~mp_sini|1,nint=50,
			panel= function(x, ...){
  				panel.histogram(x, ...)
  				#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab=expression(paste(m[p],"sini (in units of mass of the Jupiter)")) 
		);
  
		plot[[9]]<-doplot("histogram","Length of The Semi-major Axis",~aa|1,nint=50,
			panel= function(x, ...){
  				panel.histogram(x, ...)
  				#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab="Length of The Semi-major Axis (AU)" 
		);
  
		plot[[10]]<-doplot("histogram","Periastron Passage",~tp|1,nint=50,
			panel= function(x, ...){
 			panel.histogram(x, ...)
  			#panel.densityplot(x, col = 'blue', lwd=2,plot.points =FALSE) 
			},
			xlab="Periastron Passage"  
		);


		grid.newpage();
		pushViewport(viewport(layout=grid.layout(5, 2)));

		count<-1;

		for (i in 1:5){
  			for (j in 1:2){
    				pushViewport(viewport(layout.pos.row=i,layout.pos.col=j))
    				print(plot[[count]],newpage=FALSE,
    					panel.width=list(2.4, "inches"),
    					panel.height=list(0.75, "inches")
				);
    				popViewport();
    				count<-count+1;
  			}
		}

	};

}else{
	cat(" REQUIRED PACKAGES CANNOT BE FOUND\n")	
}
