/*
Author:
Sreekumar Thaithara Balan 

Name:
control_system.cc

Version:
0.7

Last modified:
30-03-2008

Purpose:

1. Defines the interface Mcmc

Implements:

Todo:

References:

License:
GNU General Public License
This file is part of Exofit.

Exofit is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Exofit is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Exofit; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.

*/

#ifndef MCMC_H
#define MCMC_H

#include<string>
#include<fstream>
#include<vector>
#include<gsl/gsl_rng.h>
#include"update.h"

// MCMC

class Mcmc{

 public:

  Mcmc();

  // functions for changing mcmc
  void set_input_data_file(char*);
  void set_take_state_data(bool);
  void set_take_mcmc_data(bool);

  // the mcmc
  void run();

 private:
  char* in_fil;
  bool take_state_data;
  bool take_mcmc_data; 
};

// PARALLEL TEMPERING

class Parallel_tempering{

 public:
  Parallel_tempering();
  Parallel_tempering(int,double,double);

  // functions for examining the 0th state
  std::string get_state_label(int i) const;
  double get_state_min(int) const;
  double get_state_val(int) const;
  double get_state_prop_val(int) const;
  double get_state_max(int) const;
  int get_acceptance()const;
  
  // functions for examining the tempering levels
  int get_temp_levels() const;
  double get_max_temp() const;
  double get_n_swap() const;

  // functions for setting the tempering variables
  void set_temp_levels(int);
  void set_max_temp(double);
  void set_n_swap(double);
  void initialise(State);

  //functions for altering the state-> all levels are affected
  void set_state_val(int i,double n);
  void set_state_step_size(int,double);

  // other utiliites
  void copy_state(int i,State* s);
  void update(long int, long int, int, Update*, std::ofstream&,bool);

 private:
  std::vector<State> temper_vector;
  int temp_levels;
  double max_temp;
  double n_swap;
  int acceptance;
  const gsl_rng_type* typ;
  gsl_rng* rng;
  gsl_rng* rn[3];
  int mcmc_count;
};

// INLINES FOR CLASS PARALLEL TEMPERING 

inline Parallel_tempering::Parallel_tempering()
{
  temp_levels=15;
  max_temp=0.01;
  n_swap=20;
  acceptance=0;
  mcmc_count=0;
}
inline Parallel_tempering::Parallel_tempering(int lv, double tp, double sw)
{
  temp_levels=lv;
  max_temp=tp;
  n_swap=sw;
  acceptance=0;
  mcmc_count=0;
}
inline std::string Parallel_tempering::get_state_label(int i) const
{
  return temper_vector[0].get_para_label(i);
}
inline double Parallel_tempering::get_state_min(int i) const
{
  return temper_vector[0].get_para_min(i);
}
inline double Parallel_tempering::get_state_val(int i) const
{
  return temper_vector[0].get_para_val(i);
}
inline double Parallel_tempering::get_state_prop_val(int i) const
{
  return temper_vector[0].get_para_prop_val(i);
}
inline double Parallel_tempering::get_state_max(int i) const
{
  return temper_vector[0].get_para_max(i);
}
inline int Parallel_tempering::get_acceptance() const
{
  return acceptance;
}
inline int Parallel_tempering::get_temp_levels() const
{
  return temp_levels;
}
inline double  Parallel_tempering::get_max_temp() const
{
  return max_temp;
}
inline double  Parallel_tempering::get_n_swap() const
{
  return n_swap;
}
inline void Parallel_tempering::set_temp_levels(int n)
{
  temp_levels=n;
}
inline void Parallel_tempering::set_max_temp(double n)
{
  max_temp=n;
}
inline void Parallel_tempering::set_n_swap(double n)
{
  n_swap=n;
}

// INLINES FOR CLASS MCMC 

inline Mcmc::Mcmc()
{
  take_state_data=false;
  take_state_data=false;
}
inline void Mcmc::set_input_data_file(char* c)
{
  in_fil=c;
}
inline void Mcmc::set_take_state_data(bool b)
{
  take_state_data=b;
}
inline void Mcmc::set_take_mcmc_data(bool b)
{
  take_mcmc_data=b;
}

#endif //MCMC_H
