/*
Author:
Sreekumar Thaithara Balan 

Name:
update.cc

Version:
0.7

Last modified:
30-03-2008

Purpose:
1. Implemtes the update mechanism of the state

Implements:
1. Update::assign_all()->update.h
2. Update::assign()->update.h
3. Update::update()->update.h

Todo:
1. Modify the sigma_search to Harrio et all 2003 method

References:
1. Rosentahl
2. H. Harrio, E. Saksman and J. Tamminen,

License:
GNU General Public License
This file is part of Exofit.

Exofit is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Exofit is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Exofit; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.

*/

#include<iostream>
#include<fstream>
#include<iomanip>
#include<cmath>
#include"update.h"
#include"density.h"


void Update::assign_all(bool bl)
{
  for(int i=0;i<update_vector.size();++i)
    {
      update_vector[i]=bl;
    }
}
void Update::assign(int max,int i,bool bl)
{
  if(bl==true)
    {
      update_vector.assign(max,false);
      update_vector[i]=true;
    }
  else
    {
      update_vector.assign(max,true);
      update_vector[i]=false;
    }
}

Update::Update(int max,int i,bool bl)
{
  if(bl==true)
    {
      update_vector.assign(max,false);
      update_vector[i]=true;
    }
  else
    {
      update_vector.assign(max,true);
      update_vector[i]=false;
    }
}
void Parameter::set_rand_type(const gsl_rng_type* type=gsl_rng_default)
{
  T=type;
  r=gsl_rng_alloc(T);
}

void Parameter::set_rand_seed(long unsigned int n)
{
  gsl_rng_set(r,n);
}

void Parameter::propose()
{

  double tmp_rnd=gsl_ran_gaussian(r,ss);
  prop=v+tmp_rnd;
}

void State::set_rands(const gsl_rng_type* typ,long unsigned int SD)
{
  T=typ;
  R=gsl_rng_alloc(T);
  gsl_rng_set(R,SD);// set the seed for the state
  int j;
  long unsigned int sd; //seeds for the random number of each parameter

  for(j=0;j<state_vector.size();++j)
    {
      sd=gsl_rng_uniform_int(R,2500);
      state_vector[j].set_rand_type(typ);
      state_vector[j].set_rand_seed(sd);
    }
}

double State::current_strength()
{
  int max=state_vector.size();
  double log_prob=0;
  for(int i=0;i<max;++i)
    {
      double min=state_vector[i].get_min();
      double val=state_vector[i].get_val();
      double max=state_vector[i].get_max();

      lik->set_para(val); //set the parameters in likelihood

      prior_vector[i]->set_elements(min,val,max);
      log_prob=log_prob+prior_vector[i]->probability();
    } 
  double lh=lik->likelihood();
  log_prob=log_prob+temperature*lh;
  lik->clear_para();
  return log_prob;
}

double State::new_strength()
{
  int max=state_vector.size();
  double log_prob=0;
  for(int i=0;i<max;++i)
    {
      double min=state_vector[i].get_min();
      double pro_val=state_vector[i].get_prop_val();
      double max=state_vector[i].get_max();

      lik->set_para(pro_val); //set the parameters in likelihood

      prior_vector[i]->set_elements(min,pro_val,max);
      log_prob=log_prob+prior_vector[i]->probability();
    }

  double lh=lik->likelihood();
  log_prob=log_prob+temperature*lh;
  lik->clear_para();
  return log_prob;
}

double State::current_likelihood()// for parallel tempering
{

  int max=state_vector.size();
  for(int i=0;i<max;++i)
    {
      double val=state_vector[i].get_val();
      lik->set_para(val); //set the parameters in likelihood
    }
  double lh=lik->likelihood();
  lik->clear_para();
  return lh;
}

bool State::out_of_range()
{
  int n_state=state_vector.size();
  //check the range of the poposed state
  bool orange=false;
  for(int j=0;j<n_state;++j)
    {
      double p_max=state_vector[j].get_max();
      double p_val=state_vector[j].get_prop_val();
      double p_min=state_vector[j].get_min();
      if(p_val <=p_min || p_val >=p_max)
	{
	  orange=true;
	  break;
	}
    }
  return orange;
}


int State::update(Update* updt)
{
  int accept=0;
  int max=state_vector.size();
  if(max != updt->size())
    std::cout<<"Update and State does not match\n";
  else
    {
      double log_prob=0;
      //get the currnet bond strength-> only for the first iteration
      if(calc_strength==true)//calculate this only once
	{
	  strength=current_strength();
	  calc_strength=false;
	}      
      //propose new values for parameters
      for(int i=0;i<max;++i)
	{
	  if(updt->check(i)==true)
	    state_vector[i].propose();
	}

      //metropolis ratio
      double ratio;
      double new_str;

      // If the proposed value is in the range calculate the metro ratio
      if(out_of_range()==true)
	ratio=0;
      else
	{
	  //get the new strength
	  new_str=new_strength();	
	  ratio=exp(new_str-strength);
	}
      
      // accept/reject
      double uni_rand=gsl_rng_uniform(R);
      if(uni_rand <= ratio)//acceptance
	{
	  strength=new_str;
	  ++accept;
	  for(int k=0;k<max;++k)
	    {
	      if(updt->check(k)==true)// only the proposed value to be put in
		{
		  double tmp=state_vector[k].get_prop_val();
		  state_vector[k].set_val(tmp);
		}
	    }
	}
      else// rejection-> put the state val back into the proposed val
	{
	  for(int ii=0;ii<max;++ii)	   
	    {
	      if(updt->check(ii)==true)
		{
		  double tp=state_vector[ii].get_val();
		  state_vector[ii].set_prop_val(tp);
		}
	    }
	}

    }

  return accept;
}

void State::write_labels(std::ofstream& of,bool ind)
{
  int  max=state_vector.size();
  if(of.is_open())
    {
      if(ind==true)
	of<<"N"<<"\t";

      for(int j=0;j<max;++j)
	{
	  of<<state_vector[j].get_label()<<"\t";
	}
      of<<"G\n"; // G statnds for strength
    }
}

void State::write_extract(std::ofstream& of)
{
  int  max=state_vector.size();

  if(of.is_open())
    {
      for(int j=0;j<max;++j)
	{
	  of<<std::setprecision(10)<<state_vector[j].get_val()<<"\t";
	}
      of<<strength<<"\n";
    }
}
       
void State::write_extract(std::ofstream& of,long n)
{
  int  max=state_vector.size();

  if(of.is_open())
    of<<n<<"\t";
    {
      for(int j=0;j<max;++j)
	{
	  of<<std::setprecision(10)<<state_vector[j].get_val()<<"\t";
	}
      of<<strength<<"\n";
    }
}
